@@ -12,6 +12,11 @@ Help::Help(QWidget *parent) :
 {
     ui->setupUi(this);
 
+    //Set Button Text
+    ui->pushButtonTalk->setText(tr("[Announce] talk.maemo.org"));
+    ui->pushButtonWiki->setText(tr("Wiki"));
+    ui->pushButtonGf->setText(tr("Icons by Gentleface"));
+
 }
 
 Help::~Help()
@@ -30,3 +35,9 @@ void Help::on_pushButtonWiki_clicked()
 {
      QDesktopServices::openUrl(QUrl("http://wiki.maemo.org/Flopswap"));
 }
+
+
+void Help::on_pushButtonGf_clicked()
+{
+     QDesktopServices::openUrl(QUrl("http://www.gentleface.com"));
+}
