@@ -60,6 +60,12 @@ private slots:
 
     void initialpsb();
 
+    void ejectshow();
+
+    void ejectseen();
+
+    void disableStatus();
+
 
 private:
     Ui::MainWindow *ui;
