@@ -60,12 +60,9 @@ disk=$(awk '/dev/ {print $1}' /proc/swaps | cut -d "/" -f 3)
 #Get blocks used since boot from /proc/diskstats
 ublocks=$(awk '{if ($3=="'"$disk"'") print $10}' /proc/diskstats)
 echo $ublocks ublocks
-#Multiply blocks by 512 to get used bytes
-ubytes=$(($ublocks*512))
-#Calculate used bytes into Kb, Mb and Gb
-echo $ubytes ubytes
-ukbytes=$(($ubytes/1024))
-umbytes=$(($ubytes/1024/1024))
-ugbytes=$(($ubytes/1024/1024/1024))
-echo $ukbytes ukbytes, $umbytes umbytes, $ugbytes ugbytes
+### int32 workaround ###
+## Should measure swap >2TB ##
+umbytes=$(($ublocks/2048))
+########################
+echo $umbytes umbytes
 echo "$umbytes" > /tmp/flopswaplast && exit 1
