@@ -45,11 +45,10 @@ disk=$(awk '/dev/ {print $1}' /proc/swaps | cut -d "/" -f 3)
 #Get blocks used since boot from /proc/diskstats
 ublocks=$(awk '{if ($3=="'"$disk"'") print $10}' /proc/diskstats)
 echo $ublocks ublocks
-########### int32 workaround ##########
-###### Should measure swap upto ~2TB ###########
+### int32 workaround ###
+## Should measure swap >2TB ##
 umbytes=$(($ublocks/2048))
-ugbytes=$(($ublocks/1024))
-#############################################
+########################
 #Get Swap size from /proc/swaps
 swapsize=$(awk '{if ($1=="'"/dev/$disk"'") print $3}' /proc/swaps)
 #Divide by 1024 to get swap size in megabytes
